==> dde-dock_5.4.10.orig.tar.xz: dde-dock-5.4.10/translations/dde-dock_lt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="lt" version="2.1">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>Įskiepis %1 nėra suderinamas su sistema.</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Šalinti</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth nustatymai</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Išjungti</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Įjungti</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth nustatymai</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connecting...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Pridėti klaviatūros išdėstymą</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Data ir laikas</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12 valandų laikas</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24 valandų laikas</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Laiko nustatymai</translation>
    </message>
</context>
<context>
    <name>DeviceItem</name>
    <message>
        <source>Enable network</source>
        <translation>Įjungti tinklą</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Išjungti tinklą</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Tinklo nustatymai</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Ar tikrai norite išvalyti %1 elementų(-us)?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ištrinti</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Šis veiksmas negalės būti atkurtas</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Nežinomas įrenginys</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Nežinomas tomas</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Diskas</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Atverti</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Atjungti visus</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Leistukas</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Madinga veiksena</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Efektyvi veiksena</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Viršus</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Apačia</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Kairė</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Dešinė</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Laikyti rodomą</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Laikyti paslėptą</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Išmaniai slėpti</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Veiksena</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Vieta</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Būsena</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>Įskiepiai</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Daugiaprogramio apdorojimo rodinys</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Atskirti nuo doko</translation>
    </message>
</context>
<context>
    <name>NetworkItem</name>
    <message>
        <source>Disable wired connection</source>
        <translation>Išjungti laidinį ryšį</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Įjungti laidinį ryšį</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Išjungti belaidį ryšį</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Įjungti belaidį ryšį</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Išjungti tinklą</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Įjungti tinklą</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Tinklo nustatymai</translation>
    </message>
    <message>
        <source>Device disabled</source>
        <translation>Įrenginys išjungtas</translation>
    </message>
    <message>
        <source>Wireless connection: %1</source>
        <translation>Belaidis ryšys: %1</translation>
    </message>
    <message>
        <source>Wired connection: %1</source>
        <translation>Laidinis ryšys: %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Neprijungta</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Jungiamasi</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Prisijungta, bet nėra prieigos prie interneto</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Atjungtas tinklo laidas</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Belaidis tinklas</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Laidinis tinklas</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Tinklas</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Laidinis tinklas</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Laidinis tinklas %1</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Onboard</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nustatymai</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Energija</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Energijos nustatymai</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Talpa %1, liko %2 min.</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Talpa %1, liko %2 val. %3 min.</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Įkraunama %1, iki pilnos liko %2 min.</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Įkraunama %1, iki pilnos liko %2 val. %3 min.</translation>
    </message>
    <message>
        <source>Charged</source>
        <translation>Įkrauta</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Įkraunama %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Rodyti darbalaukį</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Atskirti nuo doko</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Energija</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Išjungti</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Pristabdyti</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Užmigdyti</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Užrakinti</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Atsijungti</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Perjungti paskyrą</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Energijos nustatymai</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Paleisti iš naujo</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Įrenginys</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Įjungti garsą</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Nutildyti</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Garso nustatymai</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Garsis %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Garsas</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Šiukšlinė</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Šiukšlinė - %1 failas</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Šiukšlinė - %1 failų</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Atverti</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Išvalyti</translation>
    </message>
</context>
<context>
    <name>TrayPlugin</name>
    <message>
        <source>System Tray</source>
        <translation>Sistemos dėklas</translation>
    </message>
</context>
<context>
    <name>WirelessList</name>
    <message>
        <source>Wireless Network</source>
        <translation>Belaidis tinklas</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Belaidis tinklas %1</translation>
    </message>
</context>
</TS>

==> dde-dock_5.5.78.orig.tar.xz: dde-dock-5.5.78/translations/dde-dock_lt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="lt">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>Įskiepis %1 nėra suderinamas su sistema.</translation>
    </message>
</context>
<context>
    <name>AirplaneModeApplet</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Išjungti</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Įjungti</translation>
    </message>
    <message>
        <source>Airplane Mode settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Šalinti</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth nustatymai</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Išjungti</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Įjungti</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth nustatymai</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connecting...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Pridėti klaviatūros išdėstymą</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Data ir laikas</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12 valandų laikas</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24 valandų laikas</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Laiko nustatymai</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Ar tikrai norite išvalyti %1 elementų(-us)?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ištrinti</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Šis veiksmas negalės būti atkurtas</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Nežinomas įrenginys</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Nežinomas tomas</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Diskas</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Atverti</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Atjungti visus</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Leistukas</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Madinga veiksena</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Efektyvi veiksena</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Viršus</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Apačia</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Kairė</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Dešinė</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Laikyti rodomą</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Laikyti paslėptą</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Išmaniai slėpti</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Veiksena</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Vieta</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Būsena</translation>
    </message>
    <message>
        <source>Dock settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ModuleWidget</name>
    <message>
        <source>Size</source>
        <translation>Dydis</translation>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>Keli ekranai</translation>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fashion mode</source>
        <translation>Madinga veiksena</translation>
    </message>
    <message>
        <source>Efficient mode</source>
        <translation>Efektyvi veiksena</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Veiksena</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Viršus</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Apačia</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Kairė</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Dešinė</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Vieta</translation>
    </message>
    <message>
        <source>Keep shown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation>Laikyti paslėptą</translation>
    </message>
    <message>
        <source>Smart hide</source>
        <translation>Išmaniai slėpti</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Būsena</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Mažas</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Didelis</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Only on main screen</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Daugiaprogramio apdorojimo rodinys</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Atskirti nuo doko</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Onboard</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nustatymai</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Energija</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Energijos nustatymai</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Talpa %1, liko %2 min.</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Talpa %1, liko %2 val. %3 min.</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Įkraunama %1, iki pilnos liko %2 min.</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Įkraunama %1, iki pilnos liko %2 val. %3 min.</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Įkraunama %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SettingsModule</name>
    <message>
        <source>Dock</source>
        <translation>Dokas</translation>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Rodyti darbalaukį</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Atskirti nuo doko</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Energija</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Išjungti</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Pristabdyti</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Užmigdyti</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Užrakinti</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Atsijungti</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Perjungti paskyrą</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Energijos nustatymai</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Paleisti iš naujo</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Įrenginys</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Įjungti garsą</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Nutildyti</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Garso nustatymai</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Garsis %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Garsas</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Šiukšlinė</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Šiukšlinė - %1 failas</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Šiukšlinė - %1 failų</translation>
    </message>
    <message>
        <source>Move to Trash</source>
        <translation>Perkelti į šiukšlinę</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Atverti</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Išvalyti</translation>
    </message>
</context>
</TS>
